@@ -30,7 +30,7 @@ class PriorityQueue:
                 raise Exception("empty")
             return heapq.heappop(self._queue)[-1]
 
-    def len(self, timeout=None):
+    def len(self):
         return len(self._queue)
 
 
